package com.yaoyicloud.service.impl;

import com.yaoyicloud.config.FilerepoProperties;
import com.yaoyicloud.service.CsoReportService;
import com.yaoyicloud.tools.OfficeUtil1;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.nio.file.Files;
import java.util.Arrays;
import java.util.List;

@Slf4j
@Service
@RequiredArgsConstructor
public class CsoReportServiceImpl implements CsoReportService {
    private final FilerepoProperties filerepoProperties;

    @Override
    public ByteArrayOutputStream saveToTempFile(byte[] fileBytes) throws Exception {
        // 1. 初始化路径和字体配置
        String imagePath = filerepoProperties.getReportImagePath();
        List<String> fontLists = Arrays.asList(filerepoProperties.getSourceHanSansCnFontMediumPath());
        // 2. 创建临时Word文件（自动清理）
        File reportTempWordFile = null;
        try {
            reportTempWordFile = File.createTempFile("temp_word_", ".docx");
            Files.write(reportTempWordFile.toPath(), fileBytes);

            String html = OfficeUtil1.convert(reportTempWordFile.getAbsolutePath(), imagePath);
            try (BufferedWriter writer2 = new BufferedWriter(new FileWriter("1.html"))) {
                writer2.write(html);
            } catch (IOException e) {
                System.err.println("写入 1.html 文件时发生错误: " + e.getMessage());
                e.printStackTrace();
            }
            String html1 = OfficeUtil1.formatHtmlCso(html);
            try (BufferedWriter writer2 = new BufferedWriter(new FileWriter("2.html"))) {
                writer2.write(html1);
            } catch (IOException e) {
                System.err.println("写入 2.html 文件时发生错误: " + e.getMessage());
                e.printStackTrace();
            }
            OfficeUtil1.convertHtmlToPdfCso(html1, fontLists, imagePath, true);
            String html2 = OfficeUtil1.formatHtml(html);

            try (BufferedWriter writer2 = new BufferedWriter(new FileWriter("3.html"))) {
                writer2.write(html2);
            } catch (IOException e) {
                System.err.println("写入 3.html 文件时发生错误: " + e.getMessage());
                e.printStackTrace();
            }
           return OfficeUtil1.convertHtmlToPdfCso(html2, fontLists, imagePath, false);
        } catch (Exception e) {
            log.error("文件转换失败", e);
            throw e;
        }
    }


    private void quietlyDelete(File file) {
        if (file != null && file.exists()) {
            try {
                Files.delete(file.toPath());
            } catch (IOException e) {
                log.warn("无法删除临时文件 {}: {}", file.getAbsolutePath(), e.getMessage());
            }
        }
    }
}
